==> faiss_1.7.0.orig.tar.gz: faiss-1.7.0/CONTRIBUTING.md <==
# Contributing to Faiss

We want to make contributing to this project as easy and transparent as
possible. 

## Our Development Process

We mainly develop Faiss within Facebook. Sometimes, we will sync the 
github version of Faiss with the internal state. 

## Pull Requests

We welcome pull requests that add significant value to Faiss. If you plan to do
a major development and contribute it back to Faiss, please contact us first before
putting too much effort into it.

1. Fork the repo and create your branch from `master`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. If you haven't already, complete the Contributor License Agreement ("CLA").

There is a Facebook internal test suite for Faiss, and we need to run 
all changes to Faiss through it.

## Contributor License Agreement ("CLA")

In order to accept your pull request, we need you to submit a CLA. You only need
to do this once to work on any of Facebook's open source projects.

Complete your CLA here: <https://code.facebook.com/cla>

## Issues

We use GitHub issues to track public bugs. Please ensure your description is
clear and has sufficient instructions to be able to reproduce the issue.

Facebook has a [bounty program](https://www.facebook.com/whitehat/) for the safe
disclosure of security bugs. In those cases, please go through the process
outlined on that page and do not file a public issue.

## Coding Style  

* 4 or 2 spaces for indentation in C++ (no tabs)
* 80 character line length (both for C++ and Python)
* C++ language level: C++11

## License

By contributing to Faiss, you agree that your contributions will be licensed
under the LICENSE file in the root directory of this source tree.

==> faiss_1.7.2.orig.tar.gz: faiss-1.7.2/CONTRIBUTING.md <==
# Contributing to Faiss

We want to make contributing to this project as easy and transparent as
possible.

## Our Development Process

We mainly develop Faiss within Facebook. Sometimes, we will sync the
github version of Faiss with the internal state.

## Pull Requests

We welcome pull requests that add significant value to Faiss. If you plan to do
a major development and contribute it back to Faiss, please contact us first before
putting too much effort into it.

1. Fork the repo and create your branch from `main`.
2. If you've added code that should be tested, add tests.
3. If you've changed APIs, update the documentation.
4. Ensure the test suite passes.
5. Make sure your code lints.
6. If you haven't already, complete the Contributor License Agreement ("CLA").

There is a Facebook internal test suite for Faiss, and we need to run
all changes to Faiss through it.

## Contributor License Agreement ("CLA")

In order to accept your pull request, we need you to submit a CLA. You only need
to do this once to work on any of Facebook's open source projects.

Complete your CLA here: <https://code.facebook.com/cla>

## Issues

We use GitHub issues to track public bugs. Please ensure your description is
clear and has sufficient instructions to be able to reproduce the issue.

Facebook has a [bounty program](https://www.facebook.com/whitehat/) for the safe
disclosure of security bugs. In those cases, please go through the process
outlined on that page and do not file a public issue.

## Coding Style

* 4 or 2 spaces for indentation in C++ (no tabs)
* 80 character line length (both for C++ and Python)
* C++ language level: C++11

## License

By contributing to Faiss, you agree that your contributions will be licensed
under the LICENSE file in the root directory of this source tree.
